@@ -179,9 +179,8 @@ describe Parallel do
     end
 
     it 'can handle to high fork rate' do
-      unless RbConfig::CONFIG["target_os"] =~ /darwin1/
-        `ruby spec/cases/parallel_high_fork_rate.rb`.should == 'OK'
-      end
+      next if RbConfig::CONFIG["target_os"].include?("darwin1") # kills macs for some reason
+      `ruby spec/cases/parallel_high_fork_rate.rb`.should == 'OK'
     end
 
     it 'does not leave processes behind while running' do
@@ -190,9 +189,8 @@ describe Parallel do
     end
 
     it "does not open unnecessary pipes" do
-      open_pipes = `lsof | grep pipe | wc -l`.to_i
-      max_pipes = `ruby spec/cases/count_open_pipes.rb`.to_i
-      (max_pipes - open_pipes).should < 400
+      max = (RbConfig::CONFIG["target_os"].include?("darwin1") ? 10 : 1800) # somehow super bad on CI
+      `ruby spec/cases/count_open_pipes.rb`.to_i.should < max
     end
   end
 
@@ -212,7 +210,10 @@ describe Parallel do
     end
 
     it "raises when a thread raises" do
+      Thread.report_on_exception = false
       lambda{ Parallel.in_threads(2){|i| raise "TEST"} }.should raise_error("TEST")
+    ensure
+      Thread.report_on_exception = true
     end
   end
 
@@ -286,6 +287,10 @@ describe Parallel do
         `METHOD=map WORKER_TYPE=#{type} ruby spec/cases/with_exception_in_start_before_finish.rb 2>&1`.should == '3 called'
       end
 
+      it "can return from break with #{type}" do
+        `METHOD=map WORKER_TYPE=#{type} ruby spec/cases/with_break.rb hi 2>&1`.should =~ /^\d{4} Parallel::Break raised - result "hi"$/
+      end
+
       it "sets Parallel.worker_number with 4 #{type}" do
         out = `METHOD=map WORKER_TYPE=#{type} ruby spec/cases/with_worker_number.rb 2>&1`
         out.should =~ /\A[0123]+\z/
@@ -467,6 +472,11 @@ describe Parallel do
       out = `ruby spec/cases/map_worker_number_isolation.rb`
       out.should == "0,1\nOK"
     end
+
+    it 'can use Timeout' do
+      out = `ruby spec/cases/timeout_in_threads.rb`
+      out.should == "OK\n"
+    end
   end
 
   describe ".map_with_index" do
